package com.usky.website.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.website.domain.SiteCategory;
import com.usky.website.mapper.SiteCategoryMapper;
import com.usky.website.service.SiteCategoryService;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 官网_栏目管理 服务实现类
 * </p>
 *
 * @author ya
 * @since 2022-08-31
 */
@Service
public class SiteCategoryServiceImpl extends AbstractCrudService<SiteCategoryMapper, SiteCategory> implements SiteCategoryService {

    @Override
    public List<SiteCategory> siteCategoryList() {
        LambdaQueryWrapper<SiteCategory> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(SiteCategory::getStatus, 1)
                .orderByAsc(SiteCategory::getSortindex);
        List<SiteCategory> list = this.list(queryWrapper);
        //取得所有parentId为0的数据，也就是一级目录
        //用于封装数据，取得他的孩子（也就是下级目录）的数据
        List<SiteCategory> list1 = list.stream().filter(subjectVO ->
                subjectVO.getPid() == 0
        ).map((menu) -> {
            menu.setChildren(getChildrenData(menu, list));
            return menu;
        }).collect(Collectors.toList());
        return list1;
    }

    private List<SiteCategory> getChildrenData(SiteCategory root, List<SiteCategory> all) {
        List<SiteCategory> children = all.stream().filter(subjectVO ->
                subjectVO.getPid() == root.getId() && !root.getCategoryName().equals("产品服务")
        ).map(subjectVO -> {
            subjectVO.setChildren(getChildrenData(subjectVO, all));
            return subjectVO;
        }).collect(Collectors.toList());
        return children;
    }

}
